@@ -22,7 +22,7 @@ import uuid
 import tempfile
 
 __author__ = "Anthony Zhang (Uberi)"
-__version__ = "3.6.1"
+__version__ = "3.6.3"
 __license__ = "BSD"
 
 try:  # attempt to use the Python 2 modules
@@ -210,12 +210,18 @@ class AudioFile(AudioSource):
 
                 # run the FLAC converter with the FLAC data to get the AIFF data
                 flac_converter = get_flac_converter()
+                if os.name == "nt":  # on Windows, specify that the process is to be started without showing a console window
+                    startup_info = subprocess.STARTUPINFO()
+                    startup_info.dwFlags |= subprocess.STARTF_USESHOWWINDOW  # specify that the wShowWindow field of `startup_info` contains a value
+                    startup_info.wShowWindow = subprocess.SW_HIDE  # specify that the console window should be hidden
+                else:
+                    startup_info = None  # default startupinfo
                 process = subprocess.Popen([
                     flac_converter,
                     "--stdout", "--totally-silent",  # put the resulting AIFF file in stdout, and make sure it's not mixed with any program output
                     "--decode", "--force-aiff-format",  # decode the FLAC file into an AIFF file
                     "-",  # the input FLAC file contents will be given in stdin
-                ], stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+                ], stdin=subprocess.PIPE, stdout=subprocess.PIPE, startupinfo=startup_info)
                 aiff_data, stderr = process.communicate(flac_data)
                 aiff_file = io.BytesIO(aiff_data)
                 try:
@@ -412,12 +418,12 @@ class AudioData(object):
         # run the FLAC converter with the WAV data to get the FLAC data
         wav_data = self.get_wav_data(convert_rate, convert_width)
         flac_converter = get_flac_converter()
-        if os.name == "nt": # on Windows, specify that the process is to be started without showing a console window
+        if os.name == "nt":  # on Windows, specify that the process is to be started without showing a console window
             startup_info = subprocess.STARTUPINFO()
-            startup_info.dwFlags |= subprocess.STARTF_USESHOWWINDOW # specify that the wShowWindow field of `startup_info` contains a value
-            startup_info.wShowWindow = subprocess.SW_HIDE # specify that the console window should be hidden
+            startup_info.dwFlags |= subprocess.STARTF_USESHOWWINDOW  # specify that the wShowWindow field of `startup_info` contains a value
+            startup_info.wShowWindow = subprocess.SW_HIDE  # specify that the console window should be hidden
         else:
-            startup_info = None # default startupinfo
+            startup_info = None  # default startupinfo
         process = subprocess.Popen([
             flac_converter,
             "--stdout", "--totally-silent",  # put the resulting FLAC file in stdout, and make sure it's not mixed with any program output
